# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0-alpha6] - 2025-02-20

### Added

- Minimal unit test suite for steering (steering#43)
- Ability to mode individual timeslots (steering#128)
- `Playlist` and `PlaylistEntry` models and endpoints (steering#251)
- Document how to set duration of playlist entries in API definition (steering#252)
- `ContentLicense` model to be referenced by `Image` and `MediaSource` (steering#256)
- `media-sources` endpoint.

### Changed

- Filter sensitive information from public API endpoints (steering#217)
- Renamed `Note` model into `Episode` (steering#249)
- Renamed `playlist` field in the `Episode` model (steering#257)
- Renamed `Playlist` and `PlaylistEntry` models into `Media` and `MediaSource` (steering#258)
- Permissions for "episode and broadcast date" (steering#263)

### Fixed

- Links not added when creating a new profile (steering#254)
- Test `test_generate_timeslots_weekends` fails on weekends (steering#255)
- Cannot edit media sources with Program Manager/Host/Host+ role (steering#259)
- Unable to create repetition schedule (steering#261)
- Can’t upload images after introduction of ContentLicense relation (steering#262)

## [1.0.0-alpha5] 2024-10-23

### Added

- `basic` and `calendar` program routes. (steering#239)
- Example Values in API (steering#111)
- Radio Station settings (steering#222)
- Permissions for editing `Host` and `UserProfile` (steering#227)
- Choice of database back-end using a database URL (steering#231)
- Permission for editing the "schedule default playlist" (steering#234)
- Settings `CORS_ALLOWED_ORIGINS` and `SITE_URL` are read from the environment (steering#245)

### Changed

- Changed the aura user and group ID from 2872 to 872.
- `playout` is now part of the program routes and generates virtual timeslot (steering#120)
- Update permission names to more descriptive terms (steering#233)
- Python version and image is 3.12 (steering#246)

### Fixed

- `ours-end` conflict solution offered in nonsensical scenarios (steering#220)
- `ours-both` assigns invalid show for second part of split episode (steering#221)
- AURA does not apply summer-winter time shift correctly (steering#225)
- when I upload a file as host, the file is not shown in dashboard (steering#226)
- Update default group permission set that is delivered on install ...the User Guide. (steering#236)
- auto-generation of notes during install/setup of AURA seems to fail (steering#238)
- as a host, I can neither view nor upload audio files (steering#247)

## Removed

- The need to assign to "Host" and "Host+" groups to become "Host+" (steering#232)
- Duplicated and/or old permissions (steering#241)
- Destroy method in `NoteViewSet` (steering#242)
- Create method in `NoteViewSet` (steering#243)

## [1.0.0-alpha4] - 2024-04-17

### Added

- `Playlist` model as placeholder for custom permissions.
- The route for `schedules` can now handle PATCH requests that don’t involve conflict resolution (steering#218)
- `RadioSettings` model, admin, serializer, viewset and route to expose them (steering#173)
- Management command and Makefile target to delete OIDC client (steering#219)

### Changed

- The image URLs are now exposed as `url` and include the protocol to avoid mixed-media warnings (steering#194)
- The `title` of a `Note` is nullable (steering#203)
- A `Note` is attached to a `Timeslot` upon creation (steering#214)

### Removed

- Nested routes for shows, show/timeslots, show/schedules, show/schedule/timeslot (aura#126)

## [1.0.0-alpha3] - 2024-02-26

### Added

- `owners` optional field in `Host` model as many-to-many reference to `User` (steering#166)
- `language` and `topic` optional fields in `Note` model (steering#169)
- `contributors` field in `Note` model (steering#159)
- `PRIVILEGED_GROUP` and `ENTITLED_GROUPS` settings to implement groups and permissions (steering#177)
- `FILTER_ACTIVE_SHOWS_USING` settings to filter active shows and OIDC scope claims (steering#175)
- `ShowManager` to annotate a show with its max (last) timeslot start (steering#175)
- `is_active` boolean field in `LinkType` model (steering#187)
- `addtimeslots` management command to renew schedules for one year (steering#108)

### Changed

- **BREAKING:** The IDs of the "owned shows" and the "public shows" are now listed as `ownedShowIds` and `publicShowIds` in the OIDC scope claims.
- `note_id` and `show_id` are read-only fields of the `TimeslotSerializer` (steering#171)
- `Note.tags` are exposed as list of strings (steering#158)
- Django’s model permissions and additional custom permissions are now used (steering#177)
- `type` in `Link` model is now foreign key reference to the `LinkType` model. The serializers expect a `typeId` (steering#187)

### Removed

- `note_id` and `show` fields from the `Timeslot` model (steering#171)
- `type` field from `LinkType` model (steering#187)
- `owner` and `slug` fields from `Note` model.

### Deprecated

- Nested routes for shows, show/timeslots, show/schedules, show/schedule/timeslot will be removed with alpha-4.

## [1.0.0-alpha2] - 2023-06-20

### Added

- `Image` concrete model to handle all instances.
- API endpoint `/api/v1/images/` to add, update and delete images.
- Add `Host` admin

### Changed

- The `Host`, `Note`, `Show` models & serializers reference the new `Image`.
- The `logo` field in the `Show` model is a reference to `Image`.
- The "conflict resolution" methods of `Schedule` are now service functions.
- Update all APIs to return attributes / properties in camelCase notation (aura#141)
- Use `_id` suffix for all object reference in REST APIs (aura#166)
- Use blank strings instead of nullable strings in REST APIs (aura#167)
- Upgrade Poetry dependencies and Django to the next LTS version (steering#137)

### Removed

- The abstract `ModelWithImageFields` from the program models.
- The `ThumbnailsMixin` from the program serializers.
- The abstract `ModelWithCreatedUpdatedFields` from the program models.

### Fixed

- use kebab-case in URLs
- don’t output invalid PPOI format
- note image should allow null values
- don’t force REST API consumers to set `repetition_of` for timeslots
- The timeslot generation leaves the `last_date` unset if it is null.
- Note.tags attribute not updated via API (steering#157)
- make subtitle field in Category a CharField

## [1.0.0-alpha1] - 2023-02-24

Initial release.
