import pytest

from program.tests.factories import CategoryFactory

pytestmark = pytest.mark.django_db


def url(category=None):
    return f"/api/v1/categories/{category.id}/" if category else "/api/v1/categories/"


def test_create_category(admin_api_client):
    data = {
        "description": "DESCRIPTION",
        "is_active": True,
        "name": "NAME",
        "slug": "category",
        "subtitle": "SUBTITLE",
    }

    response = admin_api_client.post(url(), data)

    assert response.status_code == 201

    assert response.data["description"] == data["description"]
    assert response.data["name"] == data["name"]
    assert response.data["slug"] == data["slug"]
    assert response.data["subtitle"] == data["subtitle"]


def test_retrieve_category(common_api_client1, category):
    response = common_api_client1.get(url(category=category))

    assert response.status_code == 200

    assert response.data["description"] == category.description
    assert response.data["name"] == category.name
    assert response.data["slug"] == category.slug
    assert response.data["subtitle"] == category.subtitle


def test_delete_category(admin_api_client, category):
    response = admin_api_client.delete(url(category=category))

    assert response.status_code == 204


def test_list_categories(common_api_client1):
    CATEGORIES = 3
    CategoryFactory.create_batch(size=CATEGORIES)

    response = common_api_client1.get(url())

    assert response.status_code == 200
    assert len(response.data) == CATEGORIES


def test_update_description(admin_api_client, category):
    update = {"description": "DESCRIPTION"}

    response = admin_api_client.patch(url(category=category), update)

    assert response.status_code == 200
    assert response.data["description"] == update["description"]


def test_update_is_active(admin_api_client, category):
    update = {"is_active": False}

    response = admin_api_client.patch(url(category=category), update)

    assert response.status_code == 200
    assert response.data["is_active"] == update["is_active"]


def test_update_name(admin_api_client, category):
    update = {"name": "NAME"}

    response = admin_api_client.patch(url(category=category), update)

    assert response.status_code == 200
    assert response.data["name"] == update["name"]


def test_update_slug(admin_api_client, category):
    update = {"slug": "category"}

    response = admin_api_client.patch(url(category=category), update)

    assert response.status_code == 200
    assert response.data["slug"] == update["slug"]


def test_update_subtitle(admin_api_client, category):
    update = {"subtitle": "SUBTITLE"}

    response = admin_api_client.patch(url(category=category), update)

    assert response.status_code == 200
    assert response.data["subtitle"] == update["subtitle"]
